@@ -133,6 +133,9 @@ __all__ = [
     'load',
     'datadumper',
     'dump',
+    'attrload',
+    'attrdump',
+    'typechecks',
 ]
 
 
