@@ -63,6 +63,13 @@ class Loader:
         If you know that your original data is encoded
         properly, it is better to disable this.
 
+    dictequivalence: Enabled by default.
+        Automatically convert dict-like classes to dictionary
+        when loading. This enables them to be loaded into other
+        classes.
+        At the moment it supports:
+            argparse.Namespace
+
     raiseconditionerrors: Enabled by default.
         Raises exceptions when evaluating a condition from an
         handler. When disabled, the exceptions are not raised
@@ -147,7 +154,8 @@ class Loader:
         # Forward refs dictionary
         self.frefs = {}  # type: Optional[Dict[str, Type]]
 
-
+        # Enable conversion of dict-like things to dicts, before loading
+        self.dictequivalence = True
 
         # The list of handlers to use to load the data.
         # It gets iterated in order, and the first condition
@@ -212,6 +220,12 @@ class Loader:
                 self.frefs[tname] = type_
 
         func = self.handlers[index][1]
+
+        if self.dictequivalence:
+            # Convert argparse.Namespace to dictionary
+            if hasattr(value, '_get_kwargs'):
+                value = {k: v for k,v in value._get_kwargs()}
+
         try:
             return func(self, value, type_)
         except Exception as e:
@@ -270,7 +284,12 @@ def _listload(l: Loader, value, type_) -> List:
     This loads into something like List[int]
     """
     t = type_.__args__[0]
-    return [l.load(v, t, annotation=Annotation(AnnotationType.INDEX, i)) for i, v in enumerate(value)]
+    try:
+        return [l.load(v, t, annotation=Annotation(AnnotationType.INDEX, i)) for i, v in enumerate(value)]
+    except TypeError as e:
+        if isinstance(e, TypedloadException):
+            raise
+        raise TypedloadTypeError(str(e), value=value, type_=type_)
 
 
 def _dictload(l: Loader, value, type_) -> Dict:
@@ -288,7 +307,6 @@ def _dictload(l: Loader, value, type_) -> Dict:
         raise TypedloadAttributeError(str(e), type_=type_, value=value)
 
 
-
 def _setload(l: Loader, value, type_) -> Set:
     """
     This loads into something like Set[int]
@@ -404,16 +422,13 @@ def _unionload(l: Loader, value, type_) -> Any:
 
     If no suitable type is found, an exception is raised.
     """
-
-    if hasattr(type_, '__args__'):
-        args = type_.__args__
-    elif hasattr(type_, '__union_params__'):
-        args = type_.__union_params__
-    else:
+    try:
+        args = uniontypes(type_)
+    except AttributeError:
         raise TypedloadAttributeError('The typing API for this Python version is unknown')
 
     # Do not convert basic types, if possible
-    if type(value) in set(args).intersection(l.basictypes):
+    if type(value) in args.intersection(l.basictypes):
         return value
 
     exceptions = []
